function EKF=P_EKF(varargin)
% Constructor for Extended Kalman Filter for PoseSLAM.
%
% This is a sub-type of Pose SLAM filter (P_Filter), and thus it 
% inherits all methods from the P_Filter.
%
% This type of filter estimates the robot's trajectory representing it as
% Gaussian represented in the usual mean and covariance form. 
%
% The possible parameters are
%    - Another 'P_EKF'. Copy constructor.
%    - A Gaussian given the initial estimation. Generates a new 'Extended
%      Kalman Filter'.
%
% See also P_Filter, P_TRO.

  switch nargin
    case 1
      if isa(varargin{1},'P_EKF')
        EKF=varargin{1};
      else
        if  isa(varargin{1},'Gaussian')
          F=P_Filter(varargin{1});
          
          EKF.mu=get(varargin{1},'mean');
          EKF.Sigma=get(varargin{1},'covariance');
          
          EKF=class(EKF,'P_EKF',F);
        else
          error('Wrong parameter type in P_EKF creation');
        end
      end
    otherwise
      error('Wrong number of parameters in P_EKF creation');
  end
