function EKF=UpdateLoop(EKF,linked,dS,RS)
% Adds a new loop to an EKF filter.
% 
% Updates the estimated trajectory introducing a loop closure.
% Parameters:
%     EKF: The filter with the estimated trajectory
%     linked: The pose to be linked with the current robot's pose.
%     dS: The sensor readings linking the two poses.
%     RS: The noise for the sensors.
%
% See also EKF_Update.


  l=Step2State(EKF.P_Filter,linked);
  if (l<1)
    error('Trying to form close loop with a removed pose');
  end
  
  ns=size(RS,2);
  for i=1:ns
    EKF=EKF_Update(EKF,l,dS{i},RS{i});
  end
  
  % Call the UpdateLoop for the generic filter
  EKF.P_Filter=UpdateLoop(EKF.P_Filter,linked,dS,RS);