function EKF=EKF_Prediction(EKF,d,Q)
% EKF Prediction step.
%
%   Predicton step in a 'Extended Kalman Filter'.
%   This is used when extending the trajectory (i.e., the state), with a
%   new pose.
%   It updates the mean and the covariance matrix.
%
%   Parameters
%     EKF: The filter to update
%     d: The sensor reading providing the position of the new robot's pose
%        from its predecesor pose.
%     Q: The noise of the sensor providing 'd'.
%   Outputs:
%     EKF: The updated filter with the new pose.
%
%   See also EKF_Update, TRO_Prediction, TRO_Update.

  % EKF prediction a la full SLAM, where the state is extended to estimate the
	% full trajectory.
  n=size(EKF.mu,1);

  k=get(EKF.P_Filter,'dim'); % dimensionality of the pose space
  last=n-k+1:n;
  
  P1=Pose(EKF.mu(last)); % mean for the previous pose
	
  EKF.mu=[EKF.mu ; double(Relative2Absolute(P1,d))];
  
  % Jacobians used to linarly propagate the error from previous poses
  % to the new one
  [Jp Jd]=Relative2AbsoluteJacobian(P1,d);
  
  Sp=EKF.Sigma(last,last); % Covariance of the previous pose
  Cp=EKF.Sigma(1:n,last); % Previous cross-covariance (last k columns)
  C=Cp*Jp';
  
  EKF.Sigma=[EKF.Sigma C ; C' Jp*Sp*Jp'+Jd*Q*Jd'];
  
  