function L=AllLoops(F)
% Selects all possible pairs of poses as potential loops.
%
% One of the possible loop detection procedures using the information in
% the filter.
% This is a naive procedure that propose to close loops with ALL previous
% poses. Thus, using this procedure we use a prior-less data association.
%
% Parameters
%   F: The filter from where to get the information.
% Outputs:
%   L: A cell array where each element is of the form
%       [step p] where 'step' is the identifier of the pose to be linked
%       with the current robot's pose and 'p' is the information gain of
%       closing this loop (in principle we should close first the loops 
%       that are more informative).
%
% See also NoLoops, DetectLoops, TreeDetectLoops.

  L=cell(1,F.nStates-2);
  for i=1:F.nStates-2
    L{i}.step=F.State2Step(i);
    L{i}.pd=1;
  end

