function N=DetectLoops(F,matchArea,pdRange)
% Propose loops based on the distance between poses searching linearly. 
%
% One of the procedures to detect the possible loop closure
% points from the filter information.
%
% Parameters
%   F: The filter from where to get the information.
%   matchArea: Area around the current robot's pose where to search for
%              neighbouring poses. This is a pose displacement expressed
%              in the frame of the current robot's pose.
%              This is 'v_r' in the paper.
%   pdRange: Interval [p1,p2]. If a pose has probabiliby higher than p1
%            of being in the matchArea, it is consired a neighbouring
%            pose for the current robot's pose. 
%            If the probability is above p2, the it is considered a very
%            close neighbouring pose.
%            This is 's' in the paper but here we have a range for this
%            parameter and not a single value.
%
% Outputs:
%   N: A cell array with the neighbours where each element is a struct 
%      with two field
%       step: The identifier of the neighbour pose
%       pd: The neighbouring probability (always larger than pdRange(1)
% 
% See also NoLoops, AllLoops, TreeDetectLoops.

  % default outputs
  N={};
  nn=0; %neighbours so far
  for i=1:F.nStates-1
    step=F.State2Step(i);
    pd=ProbDistance2PoseBelowThreshold(F,step,matchArea,@GetRelativeDistance2Pose);
    if (pd>pdRange(1))
      nn=nn+1;
      N{nn}.step=step;
      N{nn}.pd=pd;
    end
  end

