function Gd=GetDistance2Pose(F,step)  
% Distance from the current pose to a previous pose (estimated as a Gaussian).
%
% Returns a set of Gaussians representing the first order error
% approximation of the displacement from the current robot's pose to the
% pose at time 'step'. 
%
% The output includes one Gaussian for each dimension of the displacement
% between poses.
%
% This function is very simiar to GetRelativeDistance2Pose but here the
% pose displacement is computed in the global frame.
%
% See also GetRelativeDistance2Pose, GetGeneralDistance2Pose.


  PoseN=Pose(GetPoseMean(F,F.nSteps);
  PoseI=Pose(GetPoseMean(F,step));
  
  % First order moment of the estimation of the relative squared distance from
  % pn to pi in global coordinates
  m=double(PoseN-PoseI);
  
  MarginalSigma=GetMarginalCovariance(F,step);
  
  H=[eye(F.dim) -eye(F.dim)];
  
  % This is shared with GetRelativeDistane2Pose and it can get
  % intervals as inputs.
  Gd=GetGeneralDistance2Pose(F.dim,m,MarginalSigma,H);
