function S=GetMarginalCovariance(F,step)
% Marginal covariance between the current pose and a previous one.
%
% Returns the joint marginal covariance between the current robot's pose
% and the pose at time 'step'.
%
% The output matrix is organized such that the top left sub-matrix
% corresponds to the marginal covariance of the current robot's pose 
% and the bottom right one to marginal covariance of the at time 'step'.
%
% Note that each filter has a different way of computing the marginal
% covariances and the cross-covariances between poses. This is hidden in
% this function since it uses the GetPoseEstimation and 
% GetCrossCovarianceWithPose methods that can have particular 
% implementations for each filter.
%
% See also GetPoseEstimation, GetCrossCovarianceWithPose.

  Pi=GetPoseEstimation(F,step);
  Pn=GetPoseEstimation(F,F.nSteps);
  
  n=1:F.dim;
  i=F.dim+1:2*F.dim;
  
  S=zeros(2*F.dim,2*F.dim);
  
  S(i,i)=get(Pi,'covariance');
  S(n,n)=get(Pn,'covariance');
  S(i,n)=GetCrossCovarianceWithPose(F,step);
  S(n,i)=S(i,n)';

