function pd=GetPoseData(F,varargin)
% Defines a PoseData objects from the information stored in the filter.
%
% If only the filter F is given, then the output is a cell array with the
% PoseData objects with one entry for each one of the poses estimated by
% the filter.
%
% If we give a particular time, then the output is the PoseData object
% for the particular pose obtained at the given time.
%
% The PoseData objects include the time for the pose (this is used as
% an identifier), the mean, the marginal covariance, and data related 
% with the cross-covariance of the pose with respect to the current 
% robot's pose (matrix \Phi in the paper).
%
% See also PoseData.

  if nargin>1
    step=varargin{1};
    state=Step2State(F,step);
    if state<1
      pd=0;
    else
      m=GetPoseMean(F,step);
      S=GetPoseCovariance(F,step);
      CS=GetCrossCovarianceWithPose(F,step);
      pd=PoseData(m,S,CS,step);
    end
  else
    % get all PoseDatas
    nStates=get(F,'nStates');
    pd=cell(1,nStates);
    for i=1:nStates
      step=State2Step(F,i);
      m=GetPoseMean(F,step);
      S=GetPoseCovariance(F,step);
      CS=GetCrossCovarianceWithPose(F,step);
      pd{i}=PoseData(m,S,CS,step);
    end
  end
