function Grd=GetRelativeDistance2Pose(F,step) 
% Relative displacement between the current pose and a previous one.
%
% Returns a set of Gaussians representing the first order error
% approximation of the displacement from the current robot's pose to the
% pose at time 'step'. 
%
% The output includes one Gaussian for each dimension of the displacement
% between poses.
%
% This function is very simiar to GetDistance2Pose but here the
% pose displacement is computed in the current frame of the robot.
%
% See also GetDistance2Pose, GetGeneralDistance2Pose.

  PoseN=Pose(GetPoseMean(F,F.nSteps));
  PoseI=Pose(GetPoseMean(F,step));
  
  % First order moment of the estimation of the relative distance from
  % pn to pi in the frame of Pn
  m=double(Absolute2Relative(PoseN,PoseI));
  
  MarginalSigma=GetMarginalCovariance(F,step);
  
  [Hn Hi]=Absolute2RelativeJacobian(PoseN,PoseI);
  
  % This is shared with GetDistane2Pose and it can get
  % intervals as inputs.
  Grd=GetGeneralDistance2Pose(F.dim,m,MarginalSigma,[Hn Hi]);
