function ig=InformationGain(F,R,step)
% Information gain by closing a loop with a previous pose.
%
% Computes the information gain of stablishing a link between the current
% robot's and that at time 'step' with a sensor with noise R.
%
% We take the natural logarithm and, thus, the output is given in nats.
% Just use log2 to the it in bits. If you do so you will need to
% adjust the information gain parameters accordingly.

  MarginalSigma=GetMarginalCovariance(F,step);
  
  PoseN=Pose(GetPoseMean(F,F.nSteps));
  PoseI=Pose(GetPoseMean(F,step));
  
  [Hn Hi]=Absolute2RelativeJacobian(PoseN,PoseI);
  
  S=R+[Hn Hi]*MarginalSigma*[Hn Hi]';
  
  ig=0.5*log(det(S)/det(R));
  