function p=InitFilterPlot(F,Parameters)
% Initializes the plot of a filter.
%
% Initializes the plot of the trajectory stored in a filter, F.

if Parameters.plot
  p.h=gcf;
  clf;
  rangeX=double(Parameters.Domain(1));
  rangeY=double(Parameters.Domain(2));

  axis([rangeX rangeY]);
  
  axis xy equal manual;

  hold on;

  % Get the Gaussian of the first pose
  G=F.initEstimation;

  % X-Y for the ellipse represnting the Gaussian
  p.poseXY=get(G,'ellipse');
  p.pose=line(p.poseXY(1,:),p.poseXY(2,:)); % create the ellipse representing the
  % current pose
  set(p.pose, 'color','k');

  % an point for the beginning of the trajectory
  pm=get(G,'mean');
  p.traceX=[pm(1) pm(1)];
  p.traceY=[pm(2) pm(2)];
  p.trace=line(p.traceX,p.traceY); % create the line representing the trajectory
  set(p.trace, 'marker','.' ,'markersize',15,'color','r');

  p.last=line([pm(1) pm(1)],[pm(2) pm(2)]);

  p.robotPoints=[[-0.5 0.5 -0.5 -0.5];[0.25 0 -0.25 0.25];[1 1 1 1]];

  T=[[1 0 pm(1)];[0 1 pm(2)];[0 0 1]]*[[cos(pm(3)) -sin(pm(3)) 0];[sin(pm(3)) cos(pm(3)) 0];[0 0 1]];
  rp=T*p.robotPoints;
  p.robot=line(rp(1,:),rp(2,:));
  set(p.robot,'color','b','linewidth',2);

  % a hidden line to be used to show attempts to close loops
  p.loopTest=line([0 0],[1 1],'linestyle','none');
  uistack(p.loopTest,'bottom');
else
  p=0;
end
  