function F=P_Filter(varargin)
% Construtor for the base Pose SLAM filter.
%
% The generic Pose SLAM filter provides the infraestructure common to all 
% types of Pose SLAM filters but it actually does not provide any 
% estimation of the robot's trajectory.
% 
% Possible inputs for this constructor are:
%   - Another P_Filter: Copy constructor.
%   - A Gaussian with the initial estimation for the robot's.

  switch nargin
    case 1
      if isa(varargin{1},'P_Filter')
        F=varargin{1};
      else
        if isa(varargin{1},'Gaussian')
          F.initEstimation=varargin{1};
          F.nStates=1;
          F.nSteps=1;
          
          F.Step2State=1;
          F.State2Step=1;
          
          F.dim=get(F.initEstimation,'dim');
          
          % Space to store the loops (used when plotting)
          F.nLoops=0;
          F.loops={};
          
          F=class(F,'P_Filter');
        else
          error('Wrong parameter type in P_Filter creation');
        end
      end
    otherwise
      error('Wrong number of parameters in P_Filter creation');
  end

