function pf=PlotFilter(F,Parameters,varargin)
% (Re)plots a filter.
%
% The information plotted is a trajectory and the estimation of the last
% robot's pose (in the form of an uncertainty ellipse around the robot's 
% pose)
%
% If only the filter F is given as parameter, the figure is cleared before
% plotting the filter information.
%  
% If an additional paramter is given, it must be a plot structure as that
% returned by InitFilterPlot and then the plot is done on a already
% existing figure.
%
% See also InitFilterPlot.

  % varargin is used to set whether or not to plot on the top of an
  % existing figure.

  if (nargin==2)
    pf=InitFilterPlot(F,Parameters);
  else
    pf=varargin{1};
  end
  
  % display the loop closures
  for i=1:F.nLoops
    loop=F.loops{i};
    m1=GetPoseMean(F,loop.p1);
    m2=GetPoseMean(F,loop.p2);
    l=line([m1(1) m2(1)],[m1(2) m2(2)],'color',[0 0.75 0],'marker','none','markersize',6,'linewidth',3);
    uistack(l,'top');
  end
  
  % Plot from the 2nd state to the last one
  for state=2:F.nStates
    pf=UpdateFilterPlot(F,F.State2Step(state),pf,false);
  end
    
  % show everything
  drawnow;
  