function p=ProbDistance2PoseBelowThreshold(F,step,t,distanceFunction)
% Checks if pose 'step' is close enought to the current pose. 
%
% Computes the probablity distribution on the relative displacement
% between the current robot's pose and the pose at time 'step'.
% 
% The provided 'distanceFunction' provides a one-dimensional distribution 
% for each one of the components of the displacement. This function
% integrates this distributions in the interval [-t(i), t(i)] for each
% dimension 'i' and returns the minimum of all integrals.
% Possible distanceFunctions are GetRelativeDistance2Pose,
% GetDistance2Pose.
%  
% This is equivalent to ProbDistance2PoseDataBelowThreshold but works
% single poses and not on sets of poses.
%  
% See also GetRelativeDistance2Pose, GetDistance2Pose, 
% GetRelativeDistance2Pose, ProbDistance2PoseDataBelowThreshold.

  Gd=distanceFunction(F,step);
  
  dim=get(F,'dim');
  pIn=zeros(1,dim);
  for i=1:dim
    pIn(i)=GaussianCPD(Gd{i},t(i))-GaussianCPD(Gd{i},-t(i));
  end
  p=min(pIn);
  
