function p=UpdateFilterPlot(F,step,p,redraw)
% Updates the plot of a filter with a new pose.
%
% Updates a filter plot with a new robot's pose: it extends the
% trajectory and displaces the ellipse representing the uncertainty on
% the robot's pose.
% The information used is that provided by the pose obtained at step
% 'step'. In general 'step' is the last execute simulation step but this
% function can be used to incrementaly display a previously estimated 
% trajectory (see PlotFilter).
%
% Parameter 'p' is a plot structure as returned by InitPlotFilter. The
% structure is updated and returned to use it in subsequent calls to
% UpdateFilterPlot.
%
% If parameter redraw is true a drawnow command is issued at the end of
% the plot update.
%
% See also PlotFilter, InitPlotFilter.

  % Plot in the figure selected in the initialization
  h=gcf;
  if h~=p.h
    figure(p.h);
  end
  
  % Get the curent pose: The pose for step 1 is the second pose since pose 1
  % is F.initialEstimation (i.e., it is set before starting the simulation)
  G=GetPoseEstimation(F,step);
  pm=get(G,'mean');
  
  % Replace the error ellipse with the most upt to date one
  p.poseXY=get(G,'ellipse');
  set(p.pose,'xdata',p.poseXY(1,:),'ydata',p.poseXY(2,:));
  uistack(p.pose,'top');

  % Replace the trace with the one including the new robot displacement
  p.traceX=[p.traceX pm(1)];
  p.traceY=[p.traceY pm(2)];
  set(p.trace,'xdata',p.traceX,'ydata',p.traceY);
  set(p.last,'xdata',[pm(1) pm(1)],'ydata',[pm(2) pm(2)]);
  
  % Display the polygon representing the robot
  T=[[1 0 pm(1)];[0 1 pm(2)];[0 0 1]]*[[cos(pm(3)) -sin(pm(3)) 0];[sin(pm(3)) cos(pm(3)) 0];[0 0 1]];
  rp=T*p.robotPoints;
  set(p.robot,'xdata',rp(1,:),'ydata',rp(2,:));
  uistack(p.robot,'top');
  
  % Display everything
  if redraw
    drawnow;
  end

	