function pd=GetPoseData(FF,varargin)
% Defines a PoseData objects from the information stored in the filter.
%
% If only the filter F is given, then the output is a cell array with the
% PoseData objects with one entry for each one of the poses estimated by
% the filter.
%
% If we give a particular time, then the output is the PoseData object
% for the particular pose obtained at the given time.
%
% The PoseData objects include the time for the pose, the mean, the 
% marginal covariance, and data related with the cross-covariance of the
% pose with respect to the current robot's pose.
%
% This overides the generic Filter implementation providing a faster
% access to the PoseData.
%
% See also PoseData.

  if nargin>1
    % Query for a particular posedata
    ns=Step2State(FF.P_Filter,varargin{1});
    if ns<1
      pd=0;
    else
      pd=FF.PoseData{ns};
    end
  else
    pd=FF.PoseData;
  end