function FF=Update(FF,step,SR,Sn,overwritePose)
% Adds a new pose to a TRO filter.
%
% Updates an 'TRO Filter' adding a new pose to the estimated
% trajectory. It updates the mean and the covariance matrix.
%
% Parameters:
%   FF: The filter.
%   step: Time slice.
%   SR: The sensor readingsb (cell array).
%   Sn: The noise of the sensors (cell array).
%   overwritePose: true if the last robot's pose is to be replaced by the
%                  new one.
% Returns:
%   FF: The updated 'TRO Filter'.
%
% The sensor readings are fused and the we use TRO_Prediction.
%
% See also TRO_Prediction, TRO_Update

  ns=size(SR,2);
  G=SensorFusion(1:ns,SR,Sn);
  
  d=Pose(get(G,'mean'));
  Q=get(G,'covariance');
  
  FF=TRO_Prediction(FF,d,Q,overwritePose);
  FF.P_Filter=Update(FF.P_Filter,step,overwritePose);
  
  