function FF=UpdateLoop(FF,linked,dS,RS)
% Adds a new loop to a TRO filter.
%
% Updates the estimated trajectory introducing a loop closure.
% Parameters:
%   FF: The filter with the estimated trajectory
%   linked: The pose to be linked with the current robot's pose.
%   dS: The sensor readings linking the two poses (ceel array).
%   RS: The noise for the sensors (cell array).
%
% See also FF_Update.

  l=Step2State(FF.P_Filter,linked);
  if (l<1)
    error('Trying to form close loop with a removed pose');
  end
  
  ns=size(RS,2);
  G=SensorFusion(1:ns,dS,RS);
  
  FF=TRO_Update(FF,l,Pose(get(G,'mean')),get(G,'covariance'));
  
  % Call the UpdateLoop for the generic filter
  FF.P_Filter=UpdateLoop(FF.P_Filter,linked,dS,RS);