function out=get(FF,field)
% Get function for TRO filters.
%
% Retrives information from a TRO Filter.
% The possible fields to query are
%   - Lambda: The information matrix.
%   - eta: The information vector.
%   - mu: The mean (used as a linearilation point).
%   - sigma: The inverse of Lambda. This is computed on-line and it is
%            slow to obtain.
%   - F:  the accumulation of linearizations of the displacement
%         function (see Relative2AbsoluteJacobian) from the last loop 
%         closure. This is used  to compute cross covariances of poses 
%         w.r.t. the new robot's pose.
%   - cm2ne: Size of the linear systems solved (via cholmod2) to recover
%     the state if a loop is closed. One value per each loop closure
%     operation executed.
%   - cm2t: Time to solve the linear systems solved (via cholmod2) to 
%     recover the state if a loop is closed. One value per each loop 
%     closure operation executed.
%   - cm2mb: Memory used to solve the linear systems solved (via cholmod2) 
%     to recover the state if a loop is closed. One value per each loop 
%     closure operation executed.
%
% Besides this, all the fields in a generic Filter.
%
% See also Filter/get.

  switch field
    case  'Lambda'
      out=FF.Lambda;
    case 'eta'
      out=FF.eta;
    case 'mu'
      out=FF.mu;
    case 'Sigma'
      ne=size(FF);
      out=cholmod2(FF.Lambda,sparse2(1:ne,1:ne,1));
    case 'F'
      out=FF.F;
    case 'cm2ne'
      out=FF.cm2ne;
    case 'cm2t'
      out=FF.cm2t;
    case 'cm2mb'
      out=FF.cm2mb;
    otherwise
      out=get(FF.P_Filter,field);
  end

