function T=InsertInTree(T,element)
% Inserts an element in a BTree.
%
% Adds an element to the rigth-most extrem of a BTree and then it
% rebalances the tree. Moreover, the information of the tree nodes from the
% new leaf to the root are updated with the information of the new element.
% 
% This is Algorithm 1 in the paper.
%
% See also BTree.

  if T.last==0
    % The tree is empty. Insert as a first element
    T.last=1;
    T.root=1;
    T.leaves(get(element,'id'))=T.last;
    T.data{1}.element=element;
    T.data{1}.left=0;
    T.data{1}.right=0;
    T.data{1}.heigth=1;
    T.data{1}.parent=0;
  else
    % The tree already hass element. Just add a new one.
    
    n=T.last; % last element in the tree up to now
    p=T.data{n}.parent; 
    
    n2=n+1; % place for the root of the last element up to now and
            % the element we are adding to the tree now
                
    n1=n2+1; % Place for element we are adding to the tree right now
    
    T.leaves(get(element,'id'))=n1;
    T.data{n1}.element=element;
    T.data{n1}.left=0;
    T.data{n1}.right=0;
    T.data{n1}.heigth=1;
    T.data{n1}.parent=n2;

    T.data{n}.parent=n2;

    T.data{n2}.element=Union(element,T.data{n}.element);
    T.data{n2}.left=n;
    T.data{n2}.right=n1;
    T.data{n2}.heigth=2;
    T.data{n2}.parent=p;
    
    T.last=n1;
    
    if p>0
      T.data{p}.right=n2;
    end
    
    if T.root==n
      T.root=n2;
    end
    
    % now navigate back to the root, updating the internal tree
    % nodes and re-balancing the tree
    while p~=0
      l=T.data{p}.left;
      r=T.data{p}.right;
      
      hl=T.data{l}.heigth;
      hr=T.data{r}.heigth;
      
      if hr-hl>1
        % Re-balance current node
        rr=T.data{r}.right;
        rl=T.data{r}.left;
        
        T.data{p}.left=r;
        T.data{p}.right=rr;
        
        T.data{r}.left=l;
        T.data{r}.right=rl;
        
        T.data{rr}.parent=p;
        T.data{l}.parent=r;
        
        T.data{r}.element=Union(T.data{l}.element,T.data{rl}.element);
        T.data{r}.heigth=max(T.data{l}.heigth,T.data{rl}.heigth)+1;
        
      else
        if hl-hr>1
          error('not implemented');
        end
      end
      
      l=T.data{p}.left;
      r=T.data{p}.right;
       
      T.data{p}.element=Union(T.data{l}.element,T.data{r}.element);
      T.data{p}.heigth=max(T.data{l}.heigth,T.data{r}.heigth)+1;

      % proceed up to the root
      p=T.data{p}.parent;
    end
    
  end

  
  