function rs=SearchInTree(T,F,matchArea,s,c)
% Search nearest-neighbours using a Btree
%
% Searches nearest-neighbours using a balanced tree of poses as described
% in algorithm 3 in Section VI-C of the paper.
%
% Input parameters
%   - T The BTree to search.
%   - F The Filter to use in the search
%   - matchArea The area around the previous pose where the new pose should
%               be to be considered a neighbour (this is vector 'v' in the
%               papers).
%   - s The probability threshold.
%   - c The BTree node from where to start the search. This must be the
%     root node for the initial call.
%
% See also SearchInTree, BTree, TreeDetectLoops.

   [pMin pMax]=ProbDistance2PoseDataAboveThreshold(T.data{c}.element,F,matchArea,s);

   if pMax<s
     rs={};
   else
     if pMin>s
       ids=get(T.data{c}.element,'id');
       nIds=size(ids,2);
       rs=cell(1,nIds);
       for i=1:nIds
         rs{i}=T.data{T.leaves(ids(i))}.element;
       end
     else
       if T.data{c}.heigth>1
         rsl=SearchInTree(T,F,matchArea,s,T.data{c}.left);
         rsr=SearchInTree(T,F,matchArea,s,T.data{c}.right);
         rs=[rsl rsr];
       else
         rs={T.data{c}.element};
       end
     end
   end
    