function T=UpdateTree(T,F,pd)
% Updates the information in a BTree.
%
% Updates the information stored in the leaves and the internal nodes of a
% BTree. 
%
% This function is used after loop closures, when the information for all
% poses are likely to signifiantly change and it is much faster that
% re-building the tree from scratch.
%
% This is basically an iterative implementation of the recursive pseudo-code
% given in algorithm 2 in the paper.
%
% Parameters:
%   - T The BTree.
%   - F The filter
%   - pd The set with the PoseData (mean, covariance and cross covariance
%     with the current pose) for each pose.
%
% See also BTree.

  c=T.root;
  s=0;
  done=(c==0);
  while ~done
    if T.data{c}.heigth==1
      % for leafs there is no need to go to
      % lower levels
      s=2;
    end
    switch s
      case 0
        % right tree is still to be udpated -> proceed
        c=T.data{c}.right;
        s=0;
      case 1
        % left tree is still to be updated -> proceed
        c=T.data{c}.left;
        s=0;
      case 2
        % right and left trees are updated -> update the current
        % node and go up
        if T.data{c}.heigth==1
          T.data{c}.element=pd{Step2State(F,get(T.data{c}.element,'id'))};
        else
          l=T.data{c}.left;
          r=T.data{c}.right;
          T.data{c}.element=Union(T.data{l}.element,T.data{r}.element);
        end

        % The current sub-tree is compleated, proceed with the
        % upper levels.
        % if the current sub-tree is the right branch of the upper
        % level s is set to 1 to proceed with the left branch.
        % if the current sub-tree is the left branch, we can proceed
        % to update the parent node (we move to the parent node
        % with s=2)
        p=T.data{c}.parent;
        if p==0
          done=true;
        else
          if T.data{p}.right==c
            s=1;
          else
            % if must be that T.data{p}.left==c
            s=2;
          end
          c=p;
        end
    end
  end
  