function PD=PoseData(varargin)
% PoseData constructor.
%
% The valid paramters are:
%     - Another PoseData
%     - The mean, marginal covariance, information related to the
%       cross-covariance w.r.t the last robot's pose (named \Phi_i in 
%       the paper), and the identifier of the pose .
%
% The PoseData is defined for a single pose and then function Union is
% used to accumulate the information of several poses. This is used when
% defining a tree of poses, to define the information to be stored in the
% internal nodes of the tree (they have to summarize the information in
% the leaves below the tree node).
%
% See also Union.

  switch nargin
    case 1
      if isa(varargin{1},'PoseData')
        PD=varargin{1};
      else
        error('Wrong data type in PoseData copy construtor');
      end
		case 4
      % Those could be doubles or intervals. Not check implemented: use at
      % your own risk (we could also check the sizes....)
      PD.m=varargin{1};
      PD.S=varargin{2};
      PD.CS=varargin{3};
      PD.id=varargin{4};
			PD.isInterval=(isa(PD.m,'Interval')||isa(PD.S,'Interval')||isa(PD.CS,'Interval'));
      PD=class(PD,'PoseData');
      
    otherwise
      error('Wrong number of parameters in PoseData creation');
  end
  