function out=get(PD,field)
% Get function for PoseData objects.
%
% Allows acces to the information stored in a PoseData object, PD.
%
% Possible fields to query are
%
%     - isInterval: true if the PoseData object includes intervalar
%       information, i.e, if it holds information for a collection of
%       poses.
%     - mean: The mean stored in the PoseData object. This can be a vector
%       of doubles or a vector of intervals depending on wether the
%       PoseData is refered to a single pose or to a set of poses.
%     - covaraince: The covariance stored in the PoseData object. This can
%       be a matrix of doubles or a matrix of intervals depending on wether the
%       PoseData is refered to a single pose or to a set of poses.
%     - crossCovarianceData: Data to recover the cross covariance or the
%       pose with the current robot's pose. Note that this is not directly
%       the cross-covariance (the accumulation of linarized motions are needed
%       to get the actual cross-covariances).
%     - Gaussian: A Gaussian derived from the data stored in the PoseData
%       object. This only works for PoseData objects including the
%       information of single poses.
%     - Id: identifier(s) of the pose(s) represented by the PoseData
%       object.

  switch field
    case 'isInterval'
      out=PD.isInterval;
    case 'mean'
      out=PD.m;
    case 'covariance'
      out=PD.S;
    case 'crossCovarianceData'
      out=PD.CS;
    case 'Gaussian'
      out=Gaussian(PD.m,PD.S);
    case 'id'
      out=PD.id;
    otherwise
      error('Unknown field in PoseData get');
  end