function PD=set(PD,field,varargin)
% Set functino for PoseData objects.
%
% Changes the information stored in a PoseData
% The possible fields to change are
%      - mean: The mean.
%      - covariance: The covariance.
%      - crossCovarianceData: The data from where to compute the cross covariance
%        between the current robot's pose and the pose (or poses)
%        represented by the PoseData.
%      - id: The identifier of identifiers of the poses represented by the
%        PosesData.
%      - info: Changes the mean, the covariance and the crossCovarianceData
%        in one shot.
%      - updateInfo: Changes the mean, and the crossCovarianceData
%        in one shot and decreases the covariance with a given amount.

  switch field
    case 'mean'
      PD.m=varargin{1};
    case 'covariance'
      PD.S=varargin{1};
    case 'crossCovarianceData'
      PD.CS=varargin{1};
    case 'id'
      PD.id=varargin{1};
    case 'info'
      PD.m=varargin{1};
      PD.S=varargin{2};
      PD.CS=varargin{3};
    case 'updateInfo'
      PD.m=varargin{1};
      PD.S=PD.S-varargin{2};
      PD.CS=varargin{3};
    otherwise
      error('Unknown field in PoseData set');
  end
  PD.isInterval=(isa(PD.m,'interval')||isa(PD.S,'interval')||isa(PD.CS,'interval'));
