function G=Gaussian(varargin)
% Defines a Gaussian.
%
% Multi-dimensional Gaussian constructor. The input parameters can be 
% another Gaussian, from a collection of points of from the mean and 
% covariance matrix.

  switch nargin
    case 1
      if isa(varargin{1},'Gaussian')
        G=varargin{1};
      else
        if isa(varargin{1},'double')
          % assuming we have to define the Gaussian from samples (arranged
          % in columns)
          M=size(varargin{1},2); % number of data
          m=mean(varargin{1},2);
          Pz=(varargin{1}-repmat(m,1,M)); % zero centered points
          C=(Pz*Pz')/(M-1); % unbiased covariance
          G=Gaussian(m,C);
        else
          error('Gaussian copy constructor from not a Guassian and not a raw data');
        end
      end
      
    case 2
      G.m=varargin{1};
      G.dim=size(G.m,1);
      % add a small amount of noise to the covariance to avoid
      % it to become semidefinite negative due to numerical issues
      G.S=varargin{2}+1e-6*eye(G.dim);
      
      if (G.dim~=size(G.S,1)) || (G.dim~=size(G.S,2))
        error('Non-coherent size of mean an covariance in Gaussian creation');
      end
      
      m=max(max(G.S));
      if m==0
        G.S=zeros(G.dim);
        G.d=0;
        G.iS=inf*eye(G.dim);
        G.ct=0;
      else
        R=chol(G.S);
        G.d=prod(diag(R))^2;
        iR=R\eye(G.dim);
        G.iS=iR*iR';
        G.ct=1/sqrt(((2*pi)^G.dim)*G.d);
      end
      G=class(G,'Gaussian');
    otherwise
      error('Wrong number of parameters in Gaussian constructor');
  end
