function out=get(G,field)
% Get function for Gaussians.
%
% Returns the information associated with a Gaussian
% Possible queries are
%      - dim: The dimensionality of the space where the Gaussian is defined
%      - mean:  The mean vector.
%      - covariance: The covariance matrix.
%      - invCovariance: The inverse of the covariance matrix.
%      - volume: The volume of the ellipsoid defined from the covariance matrix.
%      - normalizationFactor: The normalization factor for a Gaussian (the constant
%        that multiplies the exponential defining the Gaussian
%        distribution).
%      - ellipse: Returns a line representing the iso-countour of the
%        ellipse defined from the mean and covariance at a 90% confidence
%        value. For higher-dimensional Gaussians, we marginalize and only
%        use the first 2 components of the Gaussians.

  switch field
    case 'dim'
      out=G.dim;
    case 'mean'
      out=G.m;
    case 'covariance'
      out=G.S;
    case 'invCovariance'
      out=G.iS;
    case 'volume'
      out=G.d;
    case 'normalizationFactor'
      out=G.ct;
    case 'ellipse'
      S2d=G.S(1:2,1:2);
      % For 2 dim, a Xi squared distribution gives that the
      % 90% confidence level is obtained at 2.1459
      R=chol(S2d);
      y = 2.1459*[cos(0:0.1:2*pi);sin(0:0.1:2*pi)];
      el=R*y;
      out = [el el(:,1)]+repmat(G.m(1:2),1,size(el,2)+1);
      
    otherwise
      error('Unknow field in Gaussian get');
  end