function G=SensorFusion(range,SR,Sn)
% Fusion of noisy sensor readings.
%
% Fuses a set of sensor readings taking into account their noise.
% The fusion is implemented as a product of the Gaussian defined with the
% sensor reading as a mean and the sensor noise as covariance.
% Only valid sensor readings (sensor readings that are not NullPoses) 
% are taken into account in the fusion.
%
% Parameters:
%     - range: selects the sub-set of sensors to fuse.
%     - SR: cell array with all the sensor readings.
%     - Sn: cell array with the noise for all sensors.
%
% See also NullPose.


  first=true;
  for i=range
    d=SR{i};
    % Some sensor readings are erroneous and have not to be fused
    if ~NullPose(d)
      if first
        G=Gaussian(double(SR{i}),Sn{i});
        first=false;
      else
        G=G*Gaussian(double(SR{i}),Sn{i});
      end
    end
  end
  
  if first
    % if no valid data was provided we return a Gaussian on a NullPose
    G=Gaussian(double(SR{range(1)}),Sn{range(1)});
  end
  