function I=Interval(varargin)
 %  Interval constructor
 %
 %  Possible inputs are; another interval, a real matrix (a punctual interval
 %  is created), two real matrices (one for the lower bounds and another for 
 %  upper ones).
 %
 %  NOTE: this interval arithmetics implementation is NOT numerically
 %  save. Rounding effects are not taken into account. However, for our
 %  purposes this is not relevant.
 %  Check this
 %       http://www.ti3.tu-harburg.de/rump/intlab
 %  If you need a proper implementation of interval arithmetics in Matlab.
 
   switch nargin
     case 1
       if isa(varargin{1},'Interval')
         I=varargin{1};
       else
         if isa(varargin{1},'double')
           I=Interval(varargin{1},varargin{1});
         else
           error('Wrong parameter type in interval creation');
         end
       end
     case 2
       if isa(varargin{1},'double') && isa(varargin{2},'double')
         [r1 c1]=size(varargin{1});
         [r2 c2]=size(varargin{1});
         if (r1==r2) && (c1==c2)
           I.lower=zeros(r1,c1);
           I.upper=zeros(r1,c1);
           for i=1:r1
             for j=1:c1
               a=varargin{1}(i,j);
               b=varargin{2}(i,j);
               if b<a
                 error('Empty range in interval creation');
               end
               I.lower(i,j)=a;
               I.upper(i,j)=b;
             end
           end
           I.r=r1;
           I.c=c1;
           I=class(I,'Interval');
         else
           error('Parameter of diferent sizez in interval creation');
         end
       else
         error('Wrong parameter type in interval creation');
       end
     otherwise
       error('Wrong number of parameters in interval creation');
   end