function Iout=Union(I1,I2)
% Hull of two interval matrices.
%
% Produces the hull of two interval matrices I1, I2, i.e., the interval
% matrix that includes the two inputs.
% It accepts mixed real/interval matrices as inputs. Real matrices
% are treated as punctual interval matrices.
% If the two inputs are real, Lib/Union is used instead.
%
% See also Lib/Union.

  if isa(I1,'double')
    Iout.lower=min(I1,I2.lower);
    Iout.upper=max(I1,I2.upper);
    Iout.r=I2.r;
    Iout.c=I2.c;
  else
    if isa(I2,'double')
      Iout.lower=min(I1.lower,I2);
      Iout.upper=max(I1.upper,I2);
    else
      Iout.lower=min(I1.lower,I2.lower);
      Iout.upper=max(I1.upper,I2.upper);
    end
    Iout.r=I1.r;
    Iout.c=I1.c;
  end
  Iout=class(Iout,'Interval');
   
