function Iout=mrdivide(I1,I2)
% Element-size division between interval matrices (operator: ./).
%
% Divides two interval matrices, I1, I2.
% The second parameter can be a real or a single interval. In other
% words, right now, the general division of interval matrices is not
% implemented. This supposes to invert the second parameter and the inversion
% of an interval matrix is far from being trivial... and is not necessary 
% for our case.

  if isa(I2,'double')
    Iout=I1*(1/I2);
  else
    [nr2 nc2]=size(I2);
    if (nr2>1) || (nc2>1)
      error('Interval division is only implemented for one-dimensional intervals');
    end
    
    if (I2.lower<=0) && (I2.upper>=0)
      error('Division by zero in Interval division');
    end
    
    [nr nc]=size(I1);
    Iout.lower=zeros(nr,nc);
    Iout.upper=zeros(nr,nc);
    
    I1d=isa(I1,'double');
    for i=1:nr
      for j=1:nc
        if I1d
          v=[I1(i,j)/I2.lower I1(i,j)/I2.upper];
        else
          v=[I1.lower(i,j)/I2.lower I1.lower(i,j)/I2.upper I1.upper(i,j)/I2.lower I1.upper(i,j)/I2.upper];
        end
        
        Iout.lower(i,j)=min(v);
        Iout.upper(i,j)=max(v);
      end
    end
    Iout.r=nr;
    Iout.c=nc;
    Iout=class(Iout,'Interval');
    
  end