function Iout=power(I1,p)
% Element-wise power of an interval matrix (operator: .^).
%
% Element by element power of an interval matrix, I1 to real an exponent, p.

  if isa(p,'double')
    if ceil(p)~=p
      error('Interval power only defined on integers');
    end
    if p<0
      error('Interval power only defined on positive exponents');
    end
    
    evenPower=(mod(p,2)==0);
       
    Iout.lower=zeros(I1.r,I1.c);
    Iout.upper=zeros(I1.r,I1.c);
    
    for i=1:I1.r
      for j=1:I1.c
        a=I1.lower(i,j).^p;
        b=I1.upper(i,j).^p;
        
        if (evenPower) && (I1.lower(i,j)<=0) && (I1.upper(i,j)>=0) 
          Iout.lower(i,j)=0;
        else
          Iout.lower(i,j)=min(a,b);
        end
        Iout.upper(i,j)=max(a,b);
      end
    end
    Iout.r=I1.r;
    Iout.c=I1.c;
    Iout=class(Iout,'Interval');
  else
    error('Interval power is only implemented with real exponents');
  end