function R=ContinueSimulation(Result,varargin)
% Continues a previous partial simulation.
%
% Continues a simulation from a previous run.
% The input is the Result structure out of a experiment.
%
% See also Experiment1a, Experiment1b, Experiment1c.

  F=Result.Filter;
  R=Result.Robot;
  Parameters=Result.Parameters;
  
  if nargin>1
    Parameters.maxSteps=get(F,'nSteps')+varargin{1}+1;
  else
    Parameters.maxSteps=0;
  end
  
  R=Simulation(F,R,Parameters);
  
  allFields=true;
  
  if isfield(R,'timeS')
    n=size(Result.timeS,2);
    R.timeS(1:n)=Result.timeS;
  end
  
  if isfield(R,'timeT')
    n=size(Result.timeT,2);
    R.timeT(1:n)=Result.timeT;
  end
  
  if isfield(R,'timeSA')
    n=size(Result.timeSA,2);
    R.timeSA(1:n)=Result.timeSA;
  else
    allFields=false;
  end
  
  if isfield(R,'timeLC')
    n=size(Result.timeLC,2);
    R.timeLC(1:n)=Result.timeLC;
  else
    allFields=false;
  end
  
  if isfield(R,'timeF')
    R.timeF=Result.timeF+R.timeF;
  else
    allFields=false;
  end
  
  if isfield(R,'time')
    R.time=Result.time+R.time;
  else
    allFields=false;
  end
  
  if isfield(R,'totalIG')
    R.totalIG=Result.totalIG+R.totalIG;
  end
  
  if isfield(R,'numProposedLoops')
    R.numProposedLoops=Result.numProposedLoops+R.numProposedLoops;
  end
  
  if isfield(R,'numClosedLoops')
    R.numClosedLoops=Result.numClosedLoops+R.numClosedLoops;
  end
  
  if isfield(R,'NEES')
    n=size(Result.NEES,2);
    R.NEES(1:n)=Result.NEES;
  end  
  
  if allFields && (~Parameters.quiet)
    step=get(R.Filter,'nSteps');
    fprintf('\n\nAccumulated statistics:\n');
    if isfield(R,'timeS') && isfield(R,'timeT')
      fprintf('   Execution time: %f sec (%f sec per step. Search time: %f  Tree time: %f)\n',R.time,R.time/step,sum(R.timeS),sum(R.timeT));
    else
      fprintf('   Execution time: %f sec (%f sec per step)\n',R.time,R.time/step);
    end
    fprintf('   State Augmenation time: %f\n',sum(R.timeSA));
    fprintf('   Loop Closure time     : %f\n',sum(R.timeLC)); 
    if isfield(R,'numProposedLoops') && isfield(R,'numClosedLoops')
      if Result.numProposedLoops>0
        fprintf(' Loop ratio: %u/%u=%f\n',Result.numClosedLoops,Result.numProposedLoops,Result.numClosedLoops/Result.numProposedLoops*100);
      else
        fprintf(' No loop closure was proposed\n');
      end
    end
  end
  
  