function out=get(S,field,varargin)
% Generic get for relative positioning sensors
%
% Retrives information about a relative positioning sensor.
%
% The possible fields to retive are:
%     - relativeDisplacements: The relative displacements of the robot
%       according to this sensor.
%     - absolutePoses: The pose of the robot along time according to this 
%       sensor.
%     - all the fields in a generic sensor.
%

  switch field
    
    case 'relativeDisplacements'
      out=get(SB.RawSensor,'allReadings');
      
    case 'absolutePoses'
      n=size(S);
      if n==0
        out=0;
      else
        out=cell(1,n+1);
        if nargin>2
          out{1}=Pose(varargin{1});
        else
          d=size(get(S,'reading',1)); % dim of the poses
          out{1}=Pose(zeros(d,1));
        end
        for i=1:n
          out{i+1}=Relative2Absolute(out{i},get(S,'reading',i));
        end
      end      
    otherwise
      out=get(S.Sensor,field,varargin{1:end});
  end
  
