function O=SimOdometry(varargin)
% Simulated Odometry sensor constructor.
%
% Simulated odometry sensors are useful to test algorithm with ground truth
% available.
% 
% The possible parameters are:
%     - Another simulated odometry sensor.
%     - The sensor noise and a noiless trajectory from where to generate the
%       noisy simulated sensor readings. 

  switch nargin
    case 1
      % Copy constructor
      if isa(varargin{1},'SimOdometry')
        O=varargin{1};
      else
        error('Sensor copy constructor used with an non SimOdometry object');
      end
      
    case 2 % noise + trajectory
      noise=varargin{1};
      
      Tn=AddNoise2Trajectory(varargin{2},noise);
      
      n=size(Tn)-1;
      data=cell(1,n);
      for i=1:n
        data{i}=Absolute2Relative(Tn{i},Tn{i+1});
      end
      
      S=RelPosSensor(noise,data);
      
      O=class(struct([]),'SimOdometry',S);
   
    otherwise
      error('Defining a SimOdometry sensor with the wrong number of parameters');   
  end