function [lc d n]=SensorLoopCloses(S,i,j) 
%  Checks if two sensor readigs can be properly registered.
%
%  Checks if the sensor readings at time 'i'and those at time 'j' 
%  can be registered, i.e., if they allow to get the relative displacement
%  between the two poses. If so the output 'lc' is set to true, 'd' is
%  the (noisy) displacement between the two poses and 'n' is the noise
%  of this displacement.
%
%  In this particular type of sensors, only poses closer that a given 
%  threshold are registred. The threshold is set when defining the sensor
%  (i.e., in the contructor) and we use the ground truth to assert whether
%  or not two poses are close enough.
	
  Pi=S.groundTruth{i};
  Pj=S.groundTruth{j};
  
  dij=Absolute2Relative(Pi,Pj);
  
  s=size(dij);
  lc=true;
  i=1;
  while lc && (i<=s)
    lc=(abs(dij(i))<=S.matchArea(i));
    i=i+1;
  end
  
  if lc
    n=get(S,'noise');
    % the output must be corrupted with noise
    d=AddNoise2Relative(dij,n);
  else
    d=0;
    n=0;
  end
  
