function V=SimOdometryWithLoopClosure(varargin)
% Simulated odometry with loop closure detection.
%
% This sensor includes a simulated odometry with the extra facility of
% closing loops for poses withing a given match area. This can be used, for
% instance to simulate a perfect vision system able to recognize if to
% images are taken from similar poses.
%
% The possible parameters are:
%     - Another simulated vision sensor.
%     - The sensor noise, a noiseless trajectory from where to generate the
%       noisy simulated sensor readings, and the match area (the maximum
%       displacement arount the pose where sensor readings are obtained
%       where a match with another readings is possible).
%
% See also SimOdometry.

 switch nargin
    case 1
      
      % Copy constructor
      if isa(varargin{1},'SimOdometryWithLoopClosure')
        V=varargin{1};
      else
        error('Sensor copy constructor used with an non SimOdometryWithLoopClosure object');
      end
      
    case 3 % noise + trajectory + matchArea
      
      V.groundTruth=varargin{2};
      V.matchArea=varargin{3};
      
      S=SimOdometry(varargin{1},varargin{2});
      
      V=class(V,'SimOdometryWithLoopClosure',S);
      
    otherwise
      error('Defining a SimOdometryWithLoopClosure sensor with the wrong number of parameters');
  end
